<p align="center">
  <a href="https://github.com/bhimrazy/create-py-project"><img src="https://user-images.githubusercontent.com/46085301/193515011-ba3e2858-c9cd-4c2b-8f4d-737625505b50.png" alt="Create Python Project"></a>
</p>
<p align="center">
    <em>The awesome tool to create python projects.</em>
</p>

<p align="center">
<a href="https://codecov.io/gh/bhimrazy/fastapi" target="_blank">
    <img src="https://img.shields.io/codecov/c/github/tiangolo/fastapi?color=%2334D058" alt="Coverage">
</a>
</p>

---

## Installation

Install using pip

```bash
  pip install create-py-project-by-bhimrazy
  # or
  pip install git+https://github.com/bhimrazy/create-py-project
```

## Usage/Examples

```
  $ create-py-project
  What's your Project name?: my-project
  Choose Project Template:
    1. Vannila Python Project
    2. FastAPI Project
    3. Django Project
    4. Django Project with drf and auth
    5. ML/DL Project
    : 1

  Generating....
  Completed.
  cd into my-project directory
  and then follow the instructions in the README.md file

  Thank you for using create-py-project.^_^
  Author:@bhimrazy
```

## Roadmap

> On the way.

## 👏 How to Contribute

The main purpose of this repository is to continue evolving create-py-project. We want to make contributing to this project as easy and transparent as possible. Read below to learn how you can take part in improving this project.

### Contributing Guide

The create-py-project welcomes, and depends on, contributions from developers and users in the open source community.
Read our [**Contributing Guide**][contribute] to learn about our development process, how to propose bugfixes and improvements, and how to build and test your changes to create-py-project.

[contribute]: CONTRIBUTING.md

### Code of Conduct

Everyone interacting in the create-py-project's codebases, issue trackers, and
discussion forums is expected to follow the [PyPA Code of Conduct].

[pypa code of conduct]: https://www.pypa.io/en/latest/code-of-conduct/

## Author

- [@bhimrazy](https://www.github.com/bhimrazy)

<!-- ## ✨ Contributors

Thanks goes to these incredible people:

<a href="https://github.com/jmeisele/ml-ops/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=jmeisele/ml-ops" />
</a> -->

## License

This project is licensed under the terms of the MIT license, as found in the [LICENSE][license] file.

[license]: LICENSE
